#[non_exhaustive]pub enum CanonicalJsonFieldError {
InvalidType {
path: String,
expected: CanonicalJsonType,
found: CanonicalJsonType,
},
Missing {
path: String,
},
}Expand description
Errors that can happen when trying to access a field from a CanonicalJsonObject.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidType
The field at path was expected to be of type expected, but was received as found.
Fields

expected: CanonicalJsonTypeThe type that was expected.

found: CanonicalJsonTypeThe type that was found.
Missing
A required field is missing from a JSON object.