pub struct RedactingSerializer<'a> { /* private fields */ }Expand description
CanonicalJsonObject serializer that redacts fields on the fly.
The main use case for this is to compute the hashes or signatures of an event, where the event needs to be redacted and have a few other fields removed.
This avoids having to .clone() a CanonicalJsonObject, and then to
redact() it and potentially remove other fields, and serialize it with
serde_json::to_vec().
Implementations
Sourceimpl<'a> RedactingSerializer<'a>
impl<'a> RedactingSerializer<'a>
Sourcepub fn rules(self, rules: &'a RedactionRules) -> Self
pub fn rules(self, rules: &'a RedactionRules) -> Self
Add the redaction rules to apply.
If this is set, the object to serialize must be an event with a type field.
Sourcepub fn custom_redacted_root_fields(self, fields: &'a [&'a str]) -> Self
pub fn custom_redacted_root_fields(self, fields: &'a [&'a str]) -> Self
Add custom fields to redact at the root of the object.