pub type CanonicalJsonObject = BTreeMap<String, CanonicalJsonValue>;Expand description
The inner type of CanonicalJsonValue::Object.
Aliased Type
pub struct CanonicalJsonObject { /* private fields */ }Trait Implementations
Sourceimpl CanonicalJsonObjectExt for CanonicalJsonObject
impl CanonicalJsonObjectExt for CanonicalJsonObject
Sourcefn get_as_object(
&self,
field: &str,
path: impl Into<String>,
) -> Result<Option<&CanonicalJsonObject>, CanonicalJsonFieldError>
fn get_as_object( &self, field: &str, path: impl Into<String>, ) -> Result<Option<&CanonicalJsonObject>, CanonicalJsonFieldError>
Get the given field as an object. Read more
Sourcefn get_as_object_mut(
&mut self,
field: &str,
path: impl Into<String>,
) -> Result<Option<&mut CanonicalJsonObject>, CanonicalJsonFieldError>
fn get_as_object_mut( &mut self, field: &str, path: impl Into<String>, ) -> Result<Option<&mut CanonicalJsonObject>, CanonicalJsonFieldError>
Get the given field as a mutable object. Read more
Sourcefn get_as_object_or_insert_default(
&mut self,
field: impl Into<String>,
path: impl Into<String>,
) -> Result<&mut CanonicalJsonObject, CanonicalJsonFieldError>
fn get_as_object_or_insert_default( &mut self, field: impl Into<String>, path: impl Into<String>, ) -> Result<&mut CanonicalJsonObject, CanonicalJsonFieldError>
Get the given required field as a mutable object or insert it if it is missing. Read more
Sourcefn get_as_string(
&self,
field: &str,
path: impl Into<String>,
) -> Result<Option<&str>, CanonicalJsonFieldError>
fn get_as_string( &self, field: &str, path: impl Into<String>, ) -> Result<Option<&str>, CanonicalJsonFieldError>
Get the given field as a string. Read more
Sourcefn get_as_required_object(
&self,
field: &str,
path: impl Into<String>,
) -> Result<&CanonicalJsonObject, CanonicalJsonFieldError>
fn get_as_required_object( &self, field: &str, path: impl Into<String>, ) -> Result<&CanonicalJsonObject, CanonicalJsonFieldError>
Get the given required field as an object. Read more
Sourcefn get_as_required_object_mut(
&mut self,
field: &str,
path: impl Into<String>,
) -> Result<&mut CanonicalJsonObject, CanonicalJsonFieldError>
fn get_as_required_object_mut( &mut self, field: &str, path: impl Into<String>, ) -> Result<&mut CanonicalJsonObject, CanonicalJsonFieldError>
Get the given required field as a mutable object. Read more
Sourcefn get_as_required_string(
&self,
field: &str,
path: impl Into<String>,
) -> Result<&str, CanonicalJsonFieldError>
fn get_as_required_string( &self, field: &str, path: impl Into<String>, ) -> Result<&str, CanonicalJsonFieldError>
Get the given required field as a string. Read more
Sourceimpl PartialEq<CanonicalJsonValue> for CanonicalJsonObject
impl PartialEq<CanonicalJsonValue> for CanonicalJsonObject
Sourcefn eq(&self, other: &CanonicalJsonValue) -> bool
fn eq(&self, other: &CanonicalJsonValue) -> bool
Tests for
self and other values to be equal, and is used by ==.